@@ -1,11 +1,6 @@
 from __future__ import unicode_literals
 import platform
 
-try:
-    from lacore.version import __version__
-except ImportError:
-    __version__ = "0.1.3.1"
-
 
 def get_client_info(terse=False, withplatform=True):
     if terse is True:
@@ -20,6 +15,6 @@ def get_client_info(terse=False, withplatform=True):
     return " ".join(el)
 # vim: et:sw=4:ts=4
 
-from ._version import get_versions
+from .version import get_versions
 __version__ = get_versions()['version']
 del get_versions
